summary refs log tree commit diff
path: root/kernel/rcutree.h
diff options
context:
space:
mode:
authorPaul E. McKenney <paul.mckenney@linaro.org>2012-10-08 10:54:03 -0700
committerPaul E. McKenney <paulmck@linux.vnet.ibm.com>2012-11-08 11:50:11 -0800
commit7b2e6011f150c42235c4a541d20cf6891afe878a (patch)
treea02ac239103e97847ec29183d8aaa45c385a3335 /kernel/rcutree.h
parent489832609a1ad7189d11715d8cefb457d90182c5 (diff)
downloadlinux-7b2e6011f150c42235c4a541d20cf6891afe878a.tar.gz
rcu: Rename ->onofflock to ->orphan_lock
The ->onofflock field in the rcu_state structure at one time synchronized
CPU-hotplug operations for RCU.  However, its scope has decreased over time
so that it now only protects the lists of orphaned RCU callbacks.  This
commit therefore renames it to ->orphan_lock to reflect its current use.

Signed-off-by: Paul E. McKenney <paul.mckenney@linaro.org>
Signed-off-by: Paul E. McKenney <paulmck@linux.vnet.ibm.com>
Diffstat (limited to 'kernel/rcutree.h')
-rw-r--r--kernel/rcutree.h7
1 files changed, 3 insertions, 4 deletions
diff --git a/kernel/rcutree.h b/kernel/rcutree.h
index a240f032848e..a7c945d149cf 100644
--- a/kernel/rcutree.h
+++ b/kernel/rcutree.h
@@ -383,9 +383,8 @@ struct rcu_state {
 
 	/* End of fields guarded by root rcu_node's lock. */
 
-	raw_spinlock_t onofflock ____cacheline_internodealigned_in_smp;
-						/* exclude on/offline and */
-						/*  starting new GP. */
+	raw_spinlock_t orphan_lock ____cacheline_internodealigned_in_smp;
+						/* Protect following fields. */
 	struct rcu_head *orphan_nxtlist;	/* Orphaned callbacks that */
 						/*  need a grace period. */
 	struct rcu_head **orphan_nxttail;	/* Tail of above. */
@@ -394,7 +393,7 @@ struct rcu_state {
 	struct rcu_head **orphan_donetail;	/* Tail of above. */
 	long qlen_lazy;				/* Number of lazy callbacks. */
 	long qlen;				/* Total number of callbacks. */
 	/* End of fields guarded by onofflock. */
 
 	struct mutex onoff_mutex;		/* Coordinate hotplug & GPs. */
@@ -394,7 +393,7 @@ struct rcu_state {
 	long qlen_lazy;				/* Number of lazy callbacks. */
 	long qlen;				/* Total number of callbacks. */
-	/* End of fields guarded by onofflock. */
+	/* End of fields guarded by orphan_lock. */
 
 	struct mutex onoff_mutex;		/* Coordinate hotplug & GPs. */